dovecot-2.2: imap: FETCH[x.MIME] for message/rfc822 should produ...

dovecot at dovecot.org dovecot at dovecot.org
Fri Aug 17 08:46:27 EEST 2012


details:   http://hg.dovecot.org/dovecot-2.2/rev/0c25f3ce29ef
changeset: 14912:0c25f3ce29ef
user:      Timo Sirainen <tss at iki.fi>
date:      Fri Aug 17 08:46:22 2012 +0300
description:
imap: FETCH[x.MIME] for message/rfc822 should produce empty result

diffstat:

 src/lib-imap-storage/imap-msgpart.c |  5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diffs (15 lines):

diff -r 2535dbe7c503 -r 0c25f3ce29ef src/lib-imap-storage/imap-msgpart.c
--- a/src/lib-imap-storage/imap-msgpart.c	Fri Aug 17 07:47:16 2012 +0300
+++ b/src/lib-imap-storage/imap-msgpart.c	Fri Aug 17 08:46:22 2012 +0300
@@ -526,8 +526,9 @@
 
 	switch (msgpart->fetch_type) {
 	case FETCH_MIME:
-		if (part->parent == NULL) {
-			/* root message has no MIME headers */
+		if (part->parent == NULL ||
+		    (part->parent->flags & MESSAGE_PART_FLAG_MESSAGE_RFC822) != 0) {
+			/* message/rfc822 itself has no MIME headers */
 			*part_r = NULL;
 			return 0;
 		}


More information about the dovecot-cvs mailing list